@@ -57,8 +57,8 @@ class AdobeIO:
 
         accesstoken_body = urlencode(accesstoken_body_credentials)
         # send http request
-        print(accesstoken_body)
-        print(accesstoken_url)
+        #print(accesstoken_body)
+        #print(accesstoken_url)
         res = requests.post(accesstoken_url, headers=accesstoken_headers, data=accesstoken_body)
 
         if res.status_code == 200:
@@ -90,7 +90,7 @@ class AAM(AdobeIO):
         return requests.get(self.datasourceendpoint,headers=self.auth_header(),params=params)
 
     def get_traits(self,params=None):
-        print(params)
+        #print(params)
         return requests.get(self.traitsendpoint,headers=self.auth_header(),params=params)
 
     def create_traits(self,data=None):
